@@ -1,5 +1,5 @@
 package App::gimpgitbuild::Command::build;
-$App::gimpgitbuild::Command::build::VERSION = '0.4.0';
+$App::gimpgitbuild::Command::build::VERSION = '0.6.0';
 use strict;
 use warnings;
 use 5.014;
@@ -9,6 +9,7 @@ use App::gimpgitbuild -command;
 use Path::Tiny qw/ path tempdir tempfile cwd /;
 
 use App::gimpgitbuild::API::GitBuild ();
+use Git::Sync::App                   ();
 
 sub description
 {
@@ -63,7 +64,7 @@ qq#NOCONFIGURE=1 ./autogen.sh && ./configure --prefix="$args->{prefix}" && make
     _do_system(
         {
             cmd => [
-qq#cd "$git_co" && git checkout "$args->{branch}" && ($args->{tag} || git s origin "$args->{branch}") && #
+qq#cd "$git_co" && git checkout "$args->{branch}" && ($args->{tag} || $^X -MGit::Sync::App -e "Git::Sync::App->new->run" -- sync origin "$args->{branch}") && #
                     . ( $args->{use_meson} ? $meson1 : $autoconf1 )
             ]
         }
@@ -155,7 +156,7 @@ __END__
 
 =head1 VERSION
 
-version 0.4.0
+version 0.6.0
 
 =begin foo return (
         [ "output|o=s", "Output path" ],
